==> CGAL-6.0-doc_html.tar.xz: doc_html/Periodic_3_triangulation_3/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"classPeriodic__3DelaunayTriangulationTraits__3.html#ac9be24d712f99b7312f53350ecda3206":[1,0,0,0,8],
"classPeriodic__3DelaunayTriangulationTraits__3.html#adce0c369b72a0e8becb50da3d6dc83cb":[1,0,0,0,0],
"classPeriodic__3DelaunayTriangulationTraits__3.html#aea88b45c8bfeeb87b53181d3e71b108e":[1,0,0,0,2],
"classPeriodic__3DelaunayTriangulationTraits__3.html#af9a603fe09e95c6204f77a849f5d8c9c":[1,0,0,0,7],
"classPeriodic__3Offset__3.html":[1,0,0,1],
"classPeriodic__3Offset__3.html#a0e6aab9e11b5bc32ddfd0653649fcdb5":[1,0,0,1,3],
"classPeriodic__3Offset__3.html#a14d14bb2603453e102597141c8fa2854":[1,0,0,1,6],
"classPeriodic__3Offset__3.html#a1b852506930b21b6b8eea3068cc5a752":[1,0,0,1,14],
"classPeriodic__3Offset__3.html#a2a6a919bd2375707f60611f39d457517":[1,0,0,1,15],
"classPeriodic__3Offset__3.html#a34e7a24221181c7cc5895396759a4fb3":[1,0,0,1,13],
"classPeriodic__3Offset__3.html#a35ace7d3baeeff2bd056145b08e10afe":[1,0,0,1,2],
"classPeriodic__3Offset__3.html#a35f11e3dfd8da5c828f0e099eda89d61":[1,0,0,1,5],
"classPeriodic__3Offset__3.html#a39c33064ad3bdd6a0bee7c20aad4a0e1":[1,0,0,1,1],
"classPeriodic__3Offset__3.html#a4353e28619cfa7efa990cac2b14c993f":[1,0,0,1,10],
"classPeriodic__3Offset__3.html#a959f04dc36930d1ac5ba68652df48c71":[1,0,0,1,11],
"classPeriodic__3Offset__3.html#a964c159ab3f608233fed03bbe74c2e1b":[1,0,0,1,12],
"classPeriodic__3Offset__3.html#a9c71fb81554e27e72986fb9a11d0b250":[1,0,0,1,9],
"classPeriodic__3Offset__3.html#ab5a112388442edf82af8b4eef593b96d":[1,0,0,1,7],
"classPeriodic__3Offset__3.html#abfcf1bba4ea28e78cc19d28d73a34621":[1,0,0,1,16],
"classPeriodic__3Offset__3.html#ac9db47b8702d127394cb7df12f9a76c8":[1,0,0,1,4],
"classPeriodic__3Offset__3.html#ae7030f6624229cb8f716e8db8267aa5d":[1,0,0,1,8],
"classPeriodic__3Offset__3.html#afb48f3207205f1081b947f17c1e24e13":[1,0,0,1,0],
"classPeriodic__3RegularTriangulationDSCellBase__3.html":[1,0,0,2],
"classPeriodic__3RegularTriangulationDSVertexBase__3.html":[1,0,0,3],
"classPeriodic__3RegularTriangulationTraits__3.html":[1,0,0,4],
"classPeriodic__3RegularTriangulationTraits__3.html#a0069d71d43a8a5744cf46086d10418cc":[1,0,0,4,6],
"classPeriodic__3RegularTriangulationTraits__3.html#a3a0bdce21a097db639f7d3f851a1ec30":[1,0,0,4,9],
"classPeriodic__3RegularTriangulationTraits__3.html#a441bb8623b4f34898a080bb453430f8e":[1,0,0,4,8],
"classPeriodic__3RegularTriangulationTraits__3.html#a4540e626d1c50f6677393b0b9f454df4":[1,0,0,4,0],
"classPeriodic__3RegularTriangulationTraits__3.html#a819fe9bf15447955dbf870b4918ef34e":[1,0,0,4,2],
"classPeriodic__3RegularTriangulationTraits__3.html#aa5116378ff05bbc0a29f399d0f8a46dd":[1,0,0,4,5],
"classPeriodic__3RegularTriangulationTraits__3.html#ab42e61bf14b17b42062ab5b4d3040f7a":[1,0,0,4,3],
"classPeriodic__3RegularTriangulationTraits__3.html#acbff0b92c8b88dbd6b5ff477c2727655":[1,0,0,4,7],
"classPeriodic__3RegularTriangulationTraits__3.html#ad3a954cab3c698daeb12e76c678d1b14":[1,0,0,4,1],
"classPeriodic__3RegularTriangulationTraits__3.html#ad872dc475b7008b6299f89a9f09f22d3":[1,0,0,4,4],
"classPeriodic__3RegularTriangulationTraits__3.html#afeeba12716ddcd33f52fac162320daea":[1,0,0,4,10],
"classPeriodic__3TriangulationDSCellBase__3.html":[1,0,0,5],
"classPeriodic__3TriangulationDSCellBase__3.html#a13249e6518d507a3a33656b7a2e91b38":[1,0,0,5,0],
"classPeriodic__3TriangulationDSCellBase__3.html#aee82925ec4f9ad02af83421adca30ac5":[1,0,0,5,1],
"classPeriodic__3TriangulationDSVertexBase__3.html":[1,0,0,6],
"classPeriodic__3TriangulationDSVertexBase__3.html#a51a9ccb9bf0130e5834f425aa7b48ca8":[1,0,0,6,4],
"classPeriodic__3TriangulationDSVertexBase__3.html#a9b0d67257293bf3c60f0c23021c4db16":[1,0,0,6,0],
"classPeriodic__3TriangulationDSVertexBase__3.html#aa7f0b6db61937e6320e97c6c14c8facf":[1,0,0,6,1],
"classPeriodic__3TriangulationDSVertexBase__3.html#aaa4d0181afa599febeec117da9128bb8":[1,0,0,6,2],
"classPeriodic__3TriangulationDSVertexBase__3.html#ace19a4309d4c9483a180ba09102d6740":[1,0,0,6,3],
"classPeriodic__3TriangulationTraits__3.html":[1,0,0,7],
"classPeriodic__3TriangulationTraits__3.html#a1089565c23dc2a7211d273182190d057":[1,0,0,7,22],
"classPeriodic__3TriangulationTraits__3.html#a1970bf5334e15d6beb6d7a267cebc21b":[1,0,0,7,0],
"classPeriodic__3TriangulationTraits__3.html#a34f6f23511e44e280793b0f3cae10f33":[1,0,0,7,23],
"classPeriodic__3TriangulationTraits__3.html#a3f17906a46a623d792a432a617620ed6":[1,0,0,7,15],
"classPeriodic__3TriangulationTraits__3.html#a46767981e7984104e4a0c4a937e0aab0":[1,0,0,7,12],
"classPeriodic__3TriangulationTraits__3.html#a52c6d2cf1d698f0e917081a47cc8fa9a":[1,0,0,7,2],
"classPeriodic__3TriangulationTraits__3.html#a5e364f307a9243a997c29504be660cd7":[1,0,0,7,7],
"classPeriodic__3TriangulationTraits__3.html#a5eb8e033471d672026c75f8b10410660":[1,0,0,7,9],
"classPeriodic__3TriangulationTraits__3.html#a623203cd74b41af8d2b55d6b867e87b1":[1,0,0,7,17],
"classPeriodic__3TriangulationTraits__3.html#a646fd8febaa6d4f111fb9164fa78a2f1":[1,0,0,7,14],
"classPeriodic__3TriangulationTraits__3.html#a6ce3e215469e2a65683fcf0d0ab709aa":[1,0,0,7,3],
"classPeriodic__3TriangulationTraits__3.html#a6d335215df68aab1273d9dfeccf90f7a":[1,0,0,7,21],
"classPeriodic__3TriangulationTraits__3.html#a7c030a065d8ac642b5cdf5b6fcbf884a":[1,0,0,7,10],
"classPeriodic__3TriangulationTraits__3.html#a85c9897b2c3f1e7b95d800f0419d0bca":[1,0,0,7,18],
"classPeriodic__3TriangulationTraits__3.html#a94debc5129a47166efc597b6f88ce0e0":[1,0,0,7,24],
"classPeriodic__3TriangulationTraits__3.html#a9683fec2228de6225ba39450d847d4ea":[1,0,0,7,20],
"classPeriodic__3TriangulationTraits__3.html#a981d28e11becd23606e6ded726c79bee":[1,0,0,7,1],
"classPeriodic__3TriangulationTraits__3.html#aa06713a10e0f3e888d30678928b9bf5b":[1,0,0,7,19],
"classPeriodic__3TriangulationTraits__3.html#aadfba3974064d612917e0ee52f32a50e":[1,0,0,7,11],
"classPeriodic__3TriangulationTraits__3.html#ab22cc44ec65fc2e5c03337b636b2a2ba":[1,0,0,7,6],
"classPeriodic__3TriangulationTraits__3.html#acab17e8d4452983d40164ae8968ec049":[1,0,0,7,5],
"classPeriodic__3TriangulationTraits__3.html#ad0f5ba8bd8f19feb1d216cb8b9c0ff9c":[1,0,0,7,8],
"classPeriodic__3TriangulationTraits__3.html#ad5ae22d53d9e15e489d0d9d8420c4b7b":[1,0,0,7,4],
"classPeriodic__3TriangulationTraits__3.html#ad7cbd8c041b7e5b59342b3d8b6a6c27c":[1,0,0,7,16],
"classPeriodic__3TriangulationTraits__3.html#af34ccfe6bcd8a21e6b4cdca3150d8210":[1,0,0,7,13],
"examples.html":[4],
"group__PkgPeriodic3Triangulation3Concepts.html":[1,0,0],
"group__PkgPeriodic3Triangulation3MainClasses.html":[1,0,1],
"group__PkgPeriodic3Triangulation3Ref.html":[1,0],
"group__PkgPeriodic3Triangulation3TraitsClasses.html":[1,0,2],
"index.html":[0],
"index.html":[],
"index.html#P3Triangulation3secTraits":[0,5,0],
"index.html#P3Triangulation3secTraitsK":[0,5,0,3],
"index.html#P3Triangulation3secTraitsP3DT3":[0,5,0,1],
"index.html#P3Triangulation3secTraitsP3T3":[0,5,0,0],
"index.html#P3Triangulation3secTraitsP3regularT3":[0,5,0,2],
"index.html#P3Triangulation3secdesign":[0,5],
"index.html#P3Triangulation3secexamples":[0,6],
"index.html#P3Triangulation3secexamplescolor":[0,6,1,0],
"index.html#P3Triangulation3secintro":[0,1],
"index.html#P3Triangulation3secspace":[0,0],
"index.html#P3Triangulation3sectds":[0,5,1],
"index.html#Periodic_3_triangulation_3AddingHandles":[0,6,1,1],
"index.html#Periodic_3_triangulation_3BasicExample":[0,6,0],
"index.html#Periodic_3_triangulation_3ChangingtheVertex":[0,6,1],
"index.html#Periodic_3_triangulation_3Delaunay":[0,2],
"index.html#Periodic_3_triangulation_3Design":[0,7],
"index.html#Periodic_3_triangulation_3Flexibilityofthe":[0,5,2],
"index.html#Periodic_3_triangulation_3GeometricAccess":[0,6,4],
"index.html#Periodic_3_triangulation_3LargePointSet":[0,6,3],
"index.html#Periodic_3_triangulation_3P3TR3FirstExample":[0,6,5,0],
"index.html#Periodic_3_triangulation_3P3TR3FourthExample":[0,6,5,4],
"index.html#Periodic_3_triangulation_3P3TR3PointInsertionAndVertexRemoval":[0,6,5,1],
"index.html#Periodic_3_triangulation_3P3TR3SecondExample":[0,6,5,2],
"index.html#Periodic_3_triangulation_3P3TR3ThirdExample":[0,6,5,3],
"index.html#Periodic_3_triangulation_3PeriodicAlphaShapes":[0,6,6],
"index.html#Periodic_3_triangulation_3PeriodicRegularTriangulations":[0,6,5],
"index.html#Periodic_3_triangulation_3The27sheetedCovering":[0,6,2],
"index.html#Periodic_3_triangulation_3Triangulation":[0,4],
"index.html#Periodic_3_triangulation_3regular":[0,3],
"modules.html":[1],
"pages.html":[]
};

==> CGAL-6.1-doc_html.tar.xz: doc_html/Periodic_3_triangulation_3/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"classPeriodic__3DelaunayTriangulationTraits__3.html#aa389978c75b6d48b0292fb051318a59e":[1,0,0,0,4],
"classPeriodic__3DelaunayTriangulationTraits__3.html#aa89b6eb052ece6046fe675f0a27490a3":[1,0,0,0,5],
"classPeriodic__3DelaunayTriangulationTraits__3.html#ac3e2f4329866d050df1fa3daed97f041":[1,0,0,0,11],
"classPeriodic__3DelaunayTriangulationTraits__3.html#ac9be24d712f99b7312f53350ecda3206":[1,0,0,0,8],
"classPeriodic__3DelaunayTriangulationTraits__3.html#adce0c369b72a0e8becb50da3d6dc83cb":[1,0,0,0,0],
"classPeriodic__3DelaunayTriangulationTraits__3.html#aea88b45c8bfeeb87b53181d3e71b108e":[1,0,0,0,2],
"classPeriodic__3DelaunayTriangulationTraits__3.html#af9a603fe09e95c6204f77a849f5d8c9c":[1,0,0,0,7],
"classPeriodic__3Offset__3.html":[1,0,0,1],
"classPeriodic__3Offset__3.html#a0e6aab9e11b5bc32ddfd0653649fcdb5":[1,0,0,1,3],
"classPeriodic__3Offset__3.html#a14d14bb2603453e102597141c8fa2854":[1,0,0,1,6],
"classPeriodic__3Offset__3.html#a1b852506930b21b6b8eea3068cc5a752":[1,0,0,1,14],
"classPeriodic__3Offset__3.html#a2a6a919bd2375707f60611f39d457517":[1,0,0,1,15],
"classPeriodic__3Offset__3.html#a34e7a24221181c7cc5895396759a4fb3":[1,0,0,1,13],
"classPeriodic__3Offset__3.html#a35ace7d3baeeff2bd056145b08e10afe":[1,0,0,1,2],
"classPeriodic__3Offset__3.html#a35f11e3dfd8da5c828f0e099eda89d61":[1,0,0,1,5],
"classPeriodic__3Offset__3.html#a39c33064ad3bdd6a0bee7c20aad4a0e1":[1,0,0,1,1],
"classPeriodic__3Offset__3.html#a4353e28619cfa7efa990cac2b14c993f":[1,0,0,1,10],
"classPeriodic__3Offset__3.html#a959f04dc36930d1ac5ba68652df48c71":[1,0,0,1,11],
"classPeriodic__3Offset__3.html#a964c159ab3f608233fed03bbe74c2e1b":[1,0,0,1,12],
"classPeriodic__3Offset__3.html#a9c71fb81554e27e72986fb9a11d0b250":[1,0,0,1,9],
"classPeriodic__3Offset__3.html#ab5a112388442edf82af8b4eef593b96d":[1,0,0,1,7],
"classPeriodic__3Offset__3.html#abfcf1bba4ea28e78cc19d28d73a34621":[1,0,0,1,16],
"classPeriodic__3Offset__3.html#ac9db47b8702d127394cb7df12f9a76c8":[1,0,0,1,4],
"classPeriodic__3Offset__3.html#ae7030f6624229cb8f716e8db8267aa5d":[1,0,0,1,8],
"classPeriodic__3Offset__3.html#afb48f3207205f1081b947f17c1e24e13":[1,0,0,1,0],
"classPeriodic__3RegularTriangulationDSCellBase__3.html":[1,0,0,2],
"classPeriodic__3RegularTriangulationDSVertexBase__3.html":[1,0,0,3],
"classPeriodic__3RegularTriangulationTraits__3.html":[1,0,0,4],
"classPeriodic__3RegularTriangulationTraits__3.html#a0069d71d43a8a5744cf46086d10418cc":[1,0,0,4,6],
"classPeriodic__3RegularTriangulationTraits__3.html#a3a0bdce21a097db639f7d3f851a1ec30":[1,0,0,4,9],
"classPeriodic__3RegularTriangulationTraits__3.html#a441bb8623b4f34898a080bb453430f8e":[1,0,0,4,8],
"classPeriodic__3RegularTriangulationTraits__3.html#a4540e626d1c50f6677393b0b9f454df4":[1,0,0,4,0],
"classPeriodic__3RegularTriangulationTraits__3.html#a819fe9bf15447955dbf870b4918ef34e":[1,0,0,4,2],
"classPeriodic__3RegularTriangulationTraits__3.html#aa5116378ff05bbc0a29f399d0f8a46dd":[1,0,0,4,5],
"classPeriodic__3RegularTriangulationTraits__3.html#ab42e61bf14b17b42062ab5b4d3040f7a":[1,0,0,4,3],
"classPeriodic__3RegularTriangulationTraits__3.html#acbff0b92c8b88dbd6b5ff477c2727655":[1,0,0,4,7],
"classPeriodic__3RegularTriangulationTraits__3.html#ad3a954cab3c698daeb12e76c678d1b14":[1,0,0,4,1],
"classPeriodic__3RegularTriangulationTraits__3.html#ad872dc475b7008b6299f89a9f09f22d3":[1,0,0,4,4],
"classPeriodic__3RegularTriangulationTraits__3.html#afeeba12716ddcd33f52fac162320daea":[1,0,0,4,10],
"classPeriodic__3TriangulationDSCellBase__3.html":[1,0,0,5],
"classPeriodic__3TriangulationDSCellBase__3.html#a13249e6518d507a3a33656b7a2e91b38":[1,0,0,5,0],
"classPeriodic__3TriangulationDSCellBase__3.html#aee82925ec4f9ad02af83421adca30ac5":[1,0,0,5,1],
"classPeriodic__3TriangulationDSVertexBase__3.html":[1,0,0,6],
"classPeriodic__3TriangulationDSVertexBase__3.html#a51a9ccb9bf0130e5834f425aa7b48ca8":[1,0,0,6,4],
"classPeriodic__3TriangulationDSVertexBase__3.html#a9b0d67257293bf3c60f0c23021c4db16":[1,0,0,6,0],
"classPeriodic__3TriangulationDSVertexBase__3.html#aa7f0b6db61937e6320e97c6c14c8facf":[1,0,0,6,1],
"classPeriodic__3TriangulationDSVertexBase__3.html#aaa4d0181afa599febeec117da9128bb8":[1,0,0,6,2],
"classPeriodic__3TriangulationDSVertexBase__3.html#ace19a4309d4c9483a180ba09102d6740":[1,0,0,6,3],
"classPeriodic__3TriangulationTraits__3.html":[1,0,0,7],
"classPeriodic__3TriangulationTraits__3.html#a1089565c23dc2a7211d273182190d057":[1,0,0,7,22],
"classPeriodic__3TriangulationTraits__3.html#a1970bf5334e15d6beb6d7a267cebc21b":[1,0,0,7,0],
"classPeriodic__3TriangulationTraits__3.html#a34f6f23511e44e280793b0f3cae10f33":[1,0,0,7,23],
"classPeriodic__3TriangulationTraits__3.html#a3f17906a46a623d792a432a617620ed6":[1,0,0,7,15],
"classPeriodic__3TriangulationTraits__3.html#a46767981e7984104e4a0c4a937e0aab0":[1,0,0,7,12],
"classPeriodic__3TriangulationTraits__3.html#a52c6d2cf1d698f0e917081a47cc8fa9a":[1,0,0,7,2],
"classPeriodic__3TriangulationTraits__3.html#a5e364f307a9243a997c29504be660cd7":[1,0,0,7,7],
"classPeriodic__3TriangulationTraits__3.html#a5eb8e033471d672026c75f8b10410660":[1,0,0,7,9],
"classPeriodic__3TriangulationTraits__3.html#a623203cd74b41af8d2b55d6b867e87b1":[1,0,0,7,17],
"classPeriodic__3TriangulationTraits__3.html#a646fd8febaa6d4f111fb9164fa78a2f1":[1,0,0,7,14],
"classPeriodic__3TriangulationTraits__3.html#a6ce3e215469e2a65683fcf0d0ab709aa":[1,0,0,7,3],
"classPeriodic__3TriangulationTraits__3.html#a6d335215df68aab1273d9dfeccf90f7a":[1,0,0,7,21],
"classPeriodic__3TriangulationTraits__3.html#a7c030a065d8ac642b5cdf5b6fcbf884a":[1,0,0,7,10],
"classPeriodic__3TriangulationTraits__3.html#a85c9897b2c3f1e7b95d800f0419d0bca":[1,0,0,7,18],
"classPeriodic__3TriangulationTraits__3.html#a94debc5129a47166efc597b6f88ce0e0":[1,0,0,7,24],
"classPeriodic__3TriangulationTraits__3.html#a9683fec2228de6225ba39450d847d4ea":[1,0,0,7,20],
"classPeriodic__3TriangulationTraits__3.html#a981d28e11becd23606e6ded726c79bee":[1,0,0,7,1],
"classPeriodic__3TriangulationTraits__3.html#aa06713a10e0f3e888d30678928b9bf5b":[1,0,0,7,19],
"classPeriodic__3TriangulationTraits__3.html#aadfba3974064d612917e0ee52f32a50e":[1,0,0,7,11],
"classPeriodic__3TriangulationTraits__3.html#ab22cc44ec65fc2e5c03337b636b2a2ba":[1,0,0,7,6],
"classPeriodic__3TriangulationTraits__3.html#acab17e8d4452983d40164ae8968ec049":[1,0,0,7,5],
"classPeriodic__3TriangulationTraits__3.html#ad0f5ba8bd8f19feb1d216cb8b9c0ff9c":[1,0,0,7,8],
"classPeriodic__3TriangulationTraits__3.html#ad5ae22d53d9e15e489d0d9d8420c4b7b":[1,0,0,7,4],
"classPeriodic__3TriangulationTraits__3.html#ad7cbd8c041b7e5b59342b3d8b6a6c27c":[1,0,0,7,16],
"classPeriodic__3TriangulationTraits__3.html#af34ccfe6bcd8a21e6b4cdca3150d8210":[1,0,0,7,13],
"examples.html":[4],
"group__PkgPeriodic3Triangulation3Concepts.html":[1,0,0],
"group__PkgPeriodic3Triangulation3MainClasses.html":[1,0,1],
"group__PkgPeriodic3Triangulation3Ref.html":[1,0],
"group__PkgPeriodic3Triangulation3TraitsClasses.html":[1,0,2],
"index.html":[],
"index.html":[0],
"index.html#P3Triangulation3secTraits":[0,5,0],
"index.html#P3Triangulation3secTraitsK":[0,5,0,3],
"index.html#P3Triangulation3secTraitsP3DT3":[0,5,0,1],
"index.html#P3Triangulation3secTraitsP3T3":[0,5,0,0],
"index.html#P3Triangulation3secTraitsP3regularT3":[0,5,0,2],
"index.html#P3Triangulation3secdesign":[0,5],
"index.html#P3Triangulation3secexamples":[0,6],
"index.html#P3Triangulation3secexamplescolor":[0,6,1,0],
"index.html#P3Triangulation3secintro":[0,1],
"index.html#P3Triangulation3secspace":[0,0],
"index.html#P3Triangulation3sectds":[0,5,1],
"index.html#Periodic_3_triangulation_3AddingHandles":[0,6,1,1],
"index.html#Periodic_3_triangulation_3BasicExample":[0,6,0],
"index.html#Periodic_3_triangulation_3ChangingtheVertex":[0,6,1],
"index.html#Periodic_3_triangulation_3Delaunay":[0,2],
"index.html#Periodic_3_triangulation_3Design":[0,7],
"index.html#Periodic_3_triangulation_3Flexibilityofthe":[0,5,2],
"index.html#Periodic_3_triangulation_3GeometricAccess":[0,6,4],
"index.html#Periodic_3_triangulation_3LargePointSet":[0,6,3],
"index.html#Periodic_3_triangulation_3P3TR3FirstExample":[0,6,5,0],
"index.html#Periodic_3_triangulation_3P3TR3FourthExample":[0,6,5,4],
"index.html#Periodic_3_triangulation_3P3TR3PointInsertionAndVertexRemoval":[0,6,5,1],
"index.html#Periodic_3_triangulation_3P3TR3SecondExample":[0,6,5,2],
"index.html#Periodic_3_triangulation_3P3TR3ThirdExample":[0,6,5,3],
"index.html#Periodic_3_triangulation_3PeriodicAlphaShapes":[0,6,6],
"index.html#Periodic_3_triangulation_3PeriodicRegularTriangulations":[0,6,5],
"index.html#Periodic_3_triangulation_3The27sheetedCovering":[0,6,2],
"index.html#Periodic_3_triangulation_3Triangulation":[0,4],
"index.html#Periodic_3_triangulation_3regular":[0,3],
"modules.html":[1],
"pages.html":[]
};
